Combinatorial
=============

This module implements various combinatorial functions.

bell
----

.. autoclass:: sympy.functions.combinatorial.numbers.bell
   :members:

bernoulli
---------

.. autoclass:: sympy.functions.combinatorial.numbers.bernoulli
   :members:

binomial
--------

.. autoclass:: sympy.functions.combinatorial.factorials.binomial
   :members:

catalan
-------

.. autoclass:: sympy.functions.combinatorial.numbers.catalan
   :members:


euler
-----

.. autoclass:: sympy.functions.combinatorial.numbers.euler
   :members:


factorial
---------

.. autoclass:: sympy.functions.combinatorial.factorials.factorial
   :members:

factorial2 / double factorial
-----------------------------

.. autoclass:: sympy.functions.combinatorial.factorials.factorial2
   :members:


FallingFactorial
----------------

.. autoclass:: sympy.functions.combinatorial.factorials.FallingFactorial
   :members:

fibonacci
---------

.. autoclass:: sympy.functions.combinatorial.numbers.fibonacci
   :members:

harmonic
--------

.. autoclass:: sympy.functions.combinatorial.numbers.harmonic
   :members:


lucas
-----

.. autoclass:: sympy.functions.combinatorial.numbers.lucas
   :members:


MultiFactorial
--------------

.. autoclass:: sympy.functions.combinatorial.factorials.MultiFactorial
   :members:


RisingFactorial
---------------

.. autoclass:: sympy.functions.combinatorial.factorials.RisingFactorial
   :members:
